@@ -2,10 +2,6 @@ from . import fields as fields
 from . import validators as validators
 from .app import APIFlask as APIFlask
 from .blueprint import APIBlueprint as APIBlueprint
-from .decorators import auth_required as auth_required
-from .decorators import doc as doc
-from .decorators import input as input
-from .decorators import output as output
 from .exceptions import abort as abort
 from .exceptions import HTTPError as HTTPError
 from .helpers import get_reason_phrase as get_reason_phrase
@@ -15,4 +11,4 @@ from .schemas import Schema as Schema
 from .security import HTTPBasicAuth as HTTPBasicAuth
 from .security import HTTPTokenAuth as HTTPTokenAuth
 
-__version__ = '0.11.0'
+__version__ = '1.0.0'
