@@ -31,7 +31,6 @@ from werkzeug.exceptions import HTTPException as WerkzeugHTTPException
 from .exceptions import HTTPError
 from .exceptions import _bad_schema_message
 from .helpers import get_reason_phrase
-from .route import route_shortcuts
 from .route import route_patch
 from .schemas import Schema
 from .types import ResponseReturnValueType
@@ -54,11 +53,11 @@ from .openapi import get_security_and_security_schemes
 from .ui_templates import redoc_template
 from .ui_templates import swagger_ui_template
 from .ui_templates import swagger_ui_oauth2_redirect_template
+from .scaffold import APIScaffold
 
 
 @route_patch
-@route_shortcuts
-class APIFlask(Flask):
+class APIFlask(APIScaffold, Flask):
     """The `Flask` object with some web API support.
 
     Examples:
@@ -176,6 +175,21 @@ class APIFlask(Flask):
 
             This attribute can also be configured from the config with the
             `TERMS_OF_SERVICE` configuration key. Defaults to `None`.
+        security_schemes: The security schemes of the API
+            (openapi.components.securitySchemes). Example:
+
+            ```python
+            app.security_schemes = [
+                'ApiKeyAuth': {
+                    'type': 'apiKey',
+                    'in': 'header',
+                    'name': 'X-API-Key'
+                }
+            ]
+            ```
+
+            This attribute can also be configured from the config with the
+            `SECURITY_SCHEMES` configuration key. Defaults to `None`.
         spec_callback: It stores the function object registerd by
             [`spec_processor`][apiflask.APIFlask.spec_processor]. You can also
             pass a callback function to it directly without using `spec_processor`.
@@ -224,6 +238,10 @@ class APIFlask(Flask):
             app.schema_name_resolver = schema_name_resolver
             ```
 
+    *Version changed: 1.0*
+
+    - Add instance attribute `security_schemes` as an alias of config `SECURITY_SCHEMES`.
+
     *Version changed: 0.9.0*
 
     - Add instance attribute `schema_name_resolver`.
@@ -238,6 +256,8 @@ class APIFlask(Flask):
     license: t.Optional[t.Dict[str, str]] = ConfigAttribute('LICENSE')  # type: ignore
     external_docs: t.Optional[t.Dict[str, str]] = ConfigAttribute('EXTERNAL_DOCS')  # type: ignore
     terms_of_service: t.Optional[str] = ConfigAttribute('TERMS_OF_SERVICE')  # type: ignore
+    security_schemes: t.Optional[t.Dict[str, t.Any]] = \
+        ConfigAttribute('SECURITY_SCHEMES')  # type: ignore
 
     def __init__(
         self,
@@ -319,6 +339,8 @@ class APIFlask(Flask):
         self.schema_name_resolver = self._schema_name_resolver
 
         self._spec: t.Optional[t.Union[dict, str]] = None
+        self._auth_blueprints: t.Dict[str, t.Dict[str, t.Any]] = {}
+
         self._register_openapi_blueprint()
         self._register_error_handlers()
 
@@ -329,28 +351,31 @@ class APIFlask(Flask):
 
         - Always pass an `HTTPError` instance to error handlers.
         """
-        @self.errorhandler(HTTPError)
+        @self.errorhandler(HTTPError)  # type: ignore
         def handle_http_errors(
             error: HTTPError
         ) -> ResponseReturnValueType:
             return self.error_callback(error)
 
         if self.json_errors:
-            @self.errorhandler(WerkzeugHTTPException)  # type: ignore
-            def handle_werkzeug_errors(
-                e: WerkzeugHTTPException
-            ) -> ResponseReturnValueType:
-                headers = dict(e.get_headers())
-                # remove the original MIME header
-                del headers['Content-Type']
-                error = HTTPError(
-                    e.code,
-                    message=e.name,
-                    headers=headers
-                )
-                return self.error_callback(error)
+            self._apply_error_callback_to_werkzeug_errors()
 
-    def dispatch_request(self) -> ResponseReturnValueType:
+    def _apply_error_callback_to_werkzeug_errors(self) -> None:
+        @self.errorhandler(WerkzeugHTTPException)  # type: ignore
+        def handle_werkzeug_errors(
+            e: WerkzeugHTTPException
+        ) -> ResponseReturnValueType:
+            headers = dict(e.get_headers())
+            # remove the original MIME header
+            del headers['Content-Type']
+            error = HTTPError(
+                e.code,
+                message=e.name,
+                headers=headers
+            )
+            return self.error_callback(error)
+
+    def dispatch_request(self) -> ResponseReturnValueType:  # type: ignore
         """Overwrite the default dispatch method in Flask.
 
         With this overwrite, view arguments are passed as positional
@@ -361,8 +386,8 @@ class APIFlask(Flask):
 
         ```python
         @app.get('/pets/<name>/<int:pet_id>/<age>')  # -> name, pet_id, age
-        @input(QuerySchema)  # -> query
-        @output(PetSchema)  # -> pet
+        @app.input(QuerySchema)  # -> query
+        @app.output(PetSchema)  # -> pet
         def get_pet(name, pet_id, age, query, pet):
             pass
         ```
@@ -421,18 +446,15 @@ class APIFlask(Flask):
 
         The decorated callback function will be called in the following situations:
 
-        - Any HTTP exception is raised by Flask when `APIFlask(json_errors=True)` (default).
+        - Any HTTP exception is raised by Flask when handling request.
         - A validation error happened when parsing a request.
         - An exception triggered with [`HTTPError`][apiflask.exceptions.HTTPError]
         - An exception triggered with [`abort`][apiflask.exceptions.abort].
 
-        If you have set the `json_errors` argument to `True` when creating the `app`
-        instance, this callback function will also be used for normal HTTP errors,
-        for example, 404 and 500 errors, etc. You can still register a specific error
-        handler for a specific error code or exception with the
-        `app.errorhandler(code_or_exection)` decorator, in that case, the return
-        value of the error handler will be used as the response when the corresponding
-        error or exception happened.
+        You can still register a specific error handler for a specific error code
+        or exception with the `app.errorhandler(code_or_exection)` decorator,
+        in that case, the return value of the specific error handler will be used as the
+        response when the corresponding error or exception happened.
 
         The callback function must accept an error object as argument and return a valid
         response.
@@ -495,6 +517,11 @@ class APIFlask(Flask):
         the detailed information about the validation error when the validation error
         happened.
 
+        *Version changed: 1.0*
+
+        - Apply this error processor to normal HTTP errors even when
+          `json_error` is set to `False` when creating `APIFlask` instance.
+
         *Version changed: 0.7.0*
 
         - Support registering an async callback function.
@@ -503,6 +530,7 @@ class APIFlask(Flask):
             self.error_callback = self.ensure_sync(f)
         else:  # pragma: no cover
             self.error_callback = f
+        self._apply_error_callback_to_werkzeug_errors()
         return f
 
     def _register_openapi_blueprint(self) -> None:
@@ -712,6 +740,49 @@ class APIFlask(Flask):
                     tags.append(tag)  # type: ignore
         return tags  # type: ignore
 
+    def _collect_security_info(self) -> t.Tuple[t.List[str], t.List[HTTPAuthType]]:
+        """Detect `auth_required` on blueprint before_request functions and view functions."""
+        # security schemes
+        auth_names: t.List[str] = []
+        auth_schemes: t.List[HTTPAuthType] = []
+
+        def _update_auth_info(auth: HTTPAuthType) -> None:
+            # update auth_schemes and auth_names
+            auth_schemes.append(auth)
+            auth_name: str = get_auth_name(auth, auth_names)
+            auth_names.append(auth_name)
+
+        # collect auth info on blueprint before_request functions
+        for blueprint_name, funcs in self.before_request_funcs.items():
+            # skip app-level before_request functions (blueprint_name is None)
+            if blueprint_name is None or \
+               not self.blueprints[blueprint_name].enable_openapi:  # type: ignore
+                continue
+            for f in funcs:
+                if hasattr(f, '_spec'):  # pragma: no cover
+                    auth = f._spec.get('auth')  # type: ignore
+                    if auth is not None and auth not in auth_schemes:
+                        self._auth_blueprints[blueprint_name] = {
+                            'auth': auth,
+                            'roles': f._spec.get('roles')  # type: ignore
+                        }
+                        _update_auth_info(auth)
+        # collect auth info on view functions
+        for rule in self.url_map.iter_rules():
+            view_func: ViewFuncType = self.view_functions[rule.endpoint]  # type: ignore
+            if hasattr(view_func, '_spec'):
+                auth = view_func._spec.get('auth')
+                if auth is not None and auth not in auth_schemes:
+                    _update_auth_info(auth)
+            # method views
+            if hasattr(view_func, '_method_spec'):
+                for method_spec in view_func._method_spec.values():
+                    auth = method_spec.get('auth')
+                    if auth is not None and auth not in auth_schemes:
+                        _update_auth_info(auth)
+
+        return auth_names, auth_schemes
+
     def _generate_spec(self) -> APISpec:
         """Generate the spec, return an instance of `apispec.APISpec`.
 
@@ -748,55 +819,23 @@ class APIFlask(Flask):
         )
 
         # configure flask-marshmallow URL types
-        ma_plugin.converter.field_mapping[fields.URLFor] = ('string', 'url')
-        ma_plugin.converter.field_mapping[fields.AbsoluteURLFor] = \
-            ('string', 'url')
-        if sqla is not None:  # pragma: no cover
-            ma_plugin.converter.field_mapping[sqla.HyperlinkRelated] = \
-                ('string', 'url')
-
-        # security schemes
-        auth_names: t.List[str] = []
-        auth_schemes: t.List[HTTPAuthType] = []
-        auth_blueprints: t.Dict[t.Optional[str], t.Dict[str, t.Any]] = {}
-
-        def _update_auth_info(auth: HTTPAuthType) -> None:
-            # update auth_schemes and auth_names
-            auth_schemes.append(auth)
-            auth_name: str = get_auth_name(auth, auth_names)
-            auth_names.append(auth_name)
-
-        # detect auth_required on before_request functions
-        for blueprint_name, funcs in self.before_request_funcs.items():
-            if blueprint_name is not None and \
-               not self.blueprints[blueprint_name].enable_openapi:  # type: ignore
-                continue
-            for f in funcs:
-                if hasattr(f, '_spec'):  # pragma: no cover
-                    auth = f._spec.get('auth')  # type: ignore
-                    if auth is not None and auth not in auth_schemes:
-                        auth_blueprints[blueprint_name] = {
-                            'auth': auth,
-                            'roles': f._spec.get('roles')  # type: ignore
-                        }
-                        _update_auth_info(auth)
-        # collect auth info
-        for rule in self.url_map.iter_rules():
-            view_func: ViewFuncType = self.view_functions[rule.endpoint]  # type: ignore
-            if hasattr(view_func, '_spec'):
-                auth = view_func._spec.get('auth')
-                if auth is not None and auth not in auth_schemes:
-                    _update_auth_info(auth)
-            # method views
-            if hasattr(view_func, '_method_spec'):
-                for method_spec in view_func._method_spec.values():
-                    auth = method_spec.get('auth')
-                    if auth is not None and auth not in auth_schemes:
-                        _update_auth_info(auth)
-
-        security, security_schemes = get_security_and_security_schemes(
-            auth_names, auth_schemes
+        ma_plugin.converter.field_mapping[fields.URLFor] = ('string', 'url')  # type: ignore
+        ma_plugin.converter.field_mapping[fields.AbsoluteURLFor] = (  # type: ignore
+            'string', 'url'
         )
+        if sqla is not None:  # pragma: no cover
+            ma_plugin.converter.field_mapping[sqla.HyperlinkRelated] = (  # type: ignore
+                'string', 'url'
+            )
+
+        if self.config['SECURITY_SCHEMES'] is not None:
+            security_schemes = self.config['SECURITY_SCHEMES']
+        else:
+            auth_names, auth_schemes = self._collect_security_info()
+            security, security_schemes = get_security_and_security_schemes(
+                auth_names, auth_schemes
+            )
+
         for name, scheme in security_schemes.items():
             spec.components.security_scheme(name, scheme)
 
@@ -815,10 +854,14 @@ class APIFlask(Flask):
             blueprint_name: t.Optional[str] = None  # type: ignore
             if '.' in rule.endpoint:
                 blueprint_name: str = rule.endpoint.rsplit('.', 1)[0]  # type: ignore
-                blueprint = self.blueprints[blueprint_name]  # type: ignore
-                if not hasattr(blueprint, 'enable_openapi') or \
-                   not blueprint.enable_openapi:  # type: ignore
-                    continue
+                blueprint = self.blueprints.get(blueprint_name)  # type: ignore
+                if blueprint is None:
+                    # just a normal view with dots in its endpoint, reset blueprint_name
+                    blueprint_name = None
+                else:
+                    if not hasattr(blueprint, 'enable_openapi') or \
+                       not blueprint.enable_openapi:  # type: ignore
+                        continue
             # add a default 200 response for bare views
             if not hasattr(view_func, '_spec'):
                 if self.config['AUTO_200_RESPONSE']:
@@ -837,7 +880,7 @@ class APIFlask(Flask):
                         skip = False
                 if skip:
                     continue
-            # skip views flagged with @doc(hide=True)
+            # skip views flagged with @app.doc(hide=True)
             if view_func._spec.get('hide'):
                 continue
 
@@ -933,9 +976,10 @@ class APIFlask(Flask):
                     if base_schema is not None:
                         base_schema_spec: dict
                         if isinstance(base_schema, type):
-                            base_schema_spec = ma_plugin.converter.schema2jsonschema(
-                                base_schema()
-                            )
+                            base_schema_spec = \
+                                ma_plugin.converter.schema2jsonschema(  # type: ignore
+                                    base_schema()
+                                )
                         elif isinstance(base_schema, dict):
                             base_schema_spec = base_schema
                         else:
@@ -959,8 +1003,8 @@ class APIFlask(Flask):
                         operation, status_code, schema, description, example, examples, links
                     )
                 else:
-                    # add a default 200 response for views without using @output
-                    # or @doc(responses={...})
+                    # add a default 200 response for views without using @app.output
+                    # or @app.doc(responses={...})
                     if not view_func._spec.get('responses') and self.config['AUTO_200_RESPONSE']:
                         add_response(
                             operation, '200', {}, self.config['SUCCESS_DESCRIPTION']
@@ -981,10 +1025,12 @@ class APIFlask(Flask):
                     )
 
                 # add authentication error response
+                has_bp_level_auth = blueprint_name is not None and \
+                    blueprint_name in self._auth_blueprints
+                view_func_auth = view_func._spec.get('auth')
+                custom_security = view_func._spec.get('security')
                 if self.config['AUTO_AUTH_ERROR_RESPONSE'] and \
-                   (view_func._spec.get('auth') or (
-                       blueprint_name is not None and blueprint_name in auth_blueprints
-                   )):
+                   (has_bp_level_auth or view_func_auth or custom_security):
                     status_code: str = str(  # type: ignore
                         self.config['AUTH_ERROR_STATUS_CODE']
                     )
@@ -1030,9 +1076,10 @@ class APIFlask(Flask):
 
                 # requestBody
                 if view_func._spec.get('body'):
+                    content_type = view_func._spec.get('content_type', 'application/json')
                     operation['requestBody'] = {
                         'content': {
-                            'application/json': {
+                            content_type: {
                                 'schema': view_func._spec['body'],
                             }
                         }
@@ -1040,32 +1087,41 @@ class APIFlask(Flask):
                     if view_func._spec.get('body_example'):
                         example = view_func._spec.get('body_example')
                         operation['requestBody']['content'][
-                            'application/json']['example'] = example
+                            content_type]['example'] = example
                     if view_func._spec.get('body_examples'):
                         examples = view_func._spec.get('body_examples')
                         operation['requestBody']['content'][
-                            'application/json']['examples'] = examples
+                            content_type]['examples'] = examples
 
                 # security
-                # app-wide auth
-                if None in auth_blueprints:
-                    operation['security'] = [{
-                        security[auth_blueprints[None]['auth']]:
-                            auth_blueprints[None]['roles']
-                    }]
+                if custom_security:  # custom security
+                    # TODO: validate the security name and the format
+                    operation['security'] = []
+                    operation_security = custom_security
+                    if isinstance(operation_security, str):  # 'A' -> [{'A': []}]
+                        operation['security'] = [{operation_security: []}]
+                    elif isinstance(operation_security, list):
+                        # ['A', 'B'] -> [{'A': []}, {'B': []}]
+                        if isinstance(operation_security[0], str):
+                            operation['security'] = [{name: []} for name in operation_security]
+                        else:
+                            operation['security'] = operation_security
+                    else:
+                        raise ValueError(
+                            'The operation security must be a string or a list.'
+                        )
+                else:
+                    if has_bp_level_auth:
+                        bp_auth_info = self._auth_blueprints[blueprint_name]  # type: ignore
+                        operation['security'] = [{
+                            security[bp_auth_info['auth']]: bp_auth_info['roles']
+                        }]
 
-                # blueprint-wide auth
-                if blueprint_name is not None and blueprint_name in auth_blueprints:
-                    operation['security'] = [{
-                        security[auth_blueprints[blueprint_name]['auth']]:
-                            auth_blueprints[blueprint_name]['roles']
-                    }]
-
-                # view-wide auth
-                if view_func._spec.get('auth'):
-                    operation['security'] = [{
-                        security[view_func._spec['auth']]: view_func._spec['roles']
-                    }]
+                    # view-wide auth
+                    if view_func_auth:
+                        operation['security'] = [{
+                            security[view_func_auth]: view_func._spec['roles']
+                        }]
 
                 operations[method.lower()] = operation
 
@@ -1092,6 +1148,7 @@ class APIFlask(Flask):
             for method in ['get', 'post', 'put', 'patch', 'delete']:
                 if method in operations:
                     sorted_operations[method] = operations[method]
-            spec.path(path=path, operations=sorted_operations)
+            # TODO: remove the type ignore comment when apispec 5.3.0 released
+            spec.path(path=path, operations=sorted_operations)  # type: ignore
 
         return spec
