@@ -1,7 +1,9 @@
 from marshmallow import EXCLUDE
 
 from apiflask import Schema
+from apiflask.fields import File
 from apiflask.fields import Integer
+from apiflask.fields import List
 from apiflask.fields import String
 
 
@@ -33,6 +35,23 @@ class QuerySchema(Schema):
     id = Integer(load_default=1)
 
 
+class FormSchema(Schema):
+    name = String()
+
+
+class FilesSchema(Schema):
+    image = File()
+
+
+class FilesListSchema(Schema):
+    images = List(File())
+
+
+class FormAndFilesSchema(Schema):
+    name = String()
+    image = File()
+
+
 class PaginationSchema(Schema):
     class Meta:
         unknown = EXCLUDE
