@@ -1,23 +1,28 @@
+import io
+
 import pytest
 from flask.views import MethodView
 from openapi_spec_validator import validate_spec
+from werkzeug.datastructures import FileStorage
 
 from .schemas import BarSchema
+from .schemas import FilesSchema
 from .schemas import FooSchema
+from .schemas import FormAndFilesSchema
+from .schemas import FormSchema
 from .schemas import QuerySchema
-from apiflask import input
 from apiflask.fields import String
 
 
 def test_input(app, client):
     @app.route('/foo', methods=['POST'])
-    @input(FooSchema)
+    @app.input(FooSchema)
     def foo(schema):
         return schema
 
     @app.route('/bar')
     class Bar(MethodView):
-        @input(FooSchema)
+        @app.input(FooSchema)
         def post(self, data):
             return data
 
@@ -57,8 +62,8 @@ def test_input(app, client):
 
 def test_input_with_query_location(app, client):
     @app.route('/foo', methods=['POST'])
-    @input(FooSchema, location='query')
-    @input(BarSchema, location='query')
+    @app.input(FooSchema, location='query')
+    @app.input(BarSchema, location='query')
     def foo(schema, schema2):
         return {'name': schema['name'], 'name2': schema2['name2']}
 
@@ -89,10 +94,118 @@ def test_input_with_query_location(app, client):
     assert rv.json == {'name': 'bar', 'name2': 'baz'}
 
 
+def test_input_with_form_location(app, client):
+    @app.post('/')
+    @app.input(FormSchema, location='form')
+    def index(form_data):
+        return form_data
+
+    rv = client.get('/openapi.json')
+    assert rv.status_code == 200
+    validate_spec(rv.json)
+    assert 'application/x-www-form-urlencoded' in rv.json['paths']['/']['post']['requestBody'][
+        'content']
+    assert rv.json['paths']['/']['post']['requestBody']['content'][
+        'application/x-www-form-urlencoded']['schema']['$ref'] == '#/components/schemas/Form'
+    assert 'Form' in rv.json['components']['schemas']
+
+    rv = client.post('/', data={'name': 'foo'})
+    assert rv.status_code == 200
+    assert rv.json == {'name': 'foo'}
+
+
+def test_input_with_files_location(app, client):
+    @app.post('/')
+    @app.input(FilesSchema, location='files')
+    def index(files_data):
+        data = {}
+        if 'image' in files_data and isinstance(files_data['image'], FileStorage):
+            data['image'] = True
+        return data
+
+    rv = client.get('/openapi.json')
+    assert rv.status_code == 200
+    # TODO: Failed validating 'oneOf' in schema
+    # https://github.com/p1c2u/openapi-spec-validator/issues/113
+    # validate_spec(rv.json)
+    assert 'multipart/form-data' in rv.json['paths']['/']['post']['requestBody']['content']
+    assert rv.json['paths']['/']['post']['requestBody'][
+        'content']['multipart/form-data']['schema']['$ref'] == '#/components/schemas/Files'
+    assert 'image' in rv.json['components']['schemas']['Files']['properties']
+    assert rv.json['components']['schemas']['Files']['properties']['image']['type'] == 'string'
+    assert rv.json['components']['schemas']['Files']['properties']['image']['format'] == 'binary'
+
+    rv = client.post(
+        '/',
+        data={
+            'image': (io.BytesIO(b'test'), 'test.jpg'),
+        },
+        content_type='multipart/form-data'
+    )
+    assert rv.status_code == 200
+    assert rv.json == {'image': True}
+
+
+def test_input_with_form_and_files_location(app, client):
+    @app.post('/')
+    @app.input(FormAndFilesSchema, location='form_and_files')
+    def index(form_data):
+        data = {}
+        if 'name' in form_data:
+            data['name'] = True
+        if 'image' in form_data and isinstance(form_data['image'], FileStorage):
+            data['image'] = True
+        return data
+
+    rv = client.get('/openapi.json')
+    assert rv.status_code == 200
+    # TODO: Failed validating 'oneOf' in schema
+    # https://github.com/p1c2u/openapi-spec-validator/issues/113
+    # validate_spec(rv.json)
+    assert 'multipart/form-data' in rv.json['paths']['/']['post']['requestBody']['content']
+    assert rv.json['paths']['/']['post']['requestBody'][
+        'content']['multipart/form-data']['schema']['$ref'] == '#/components/schemas/FormAndFiles'
+    assert 'name' in rv.json['components']['schemas']['FormAndFiles']['properties']
+    assert 'image' in rv.json['components']['schemas']['FormAndFiles']['properties']
+    assert rv.json['components']['schemas']['FormAndFiles']['properties']['image'][
+        'type'] == 'string'
+    assert rv.json['components']['schemas']['FormAndFiles']['properties']['image'][
+        'format'] == 'binary'
+
+    rv = client.post(
+        '/',
+        data={'name': 'foo', 'image': (io.BytesIO(b'test'), 'test.jpg')},
+        content_type='multipart/form-data'
+    )
+    assert rv.status_code == 200
+    assert rv.json == {'name': True, 'image': True}
+
+
+@pytest.mark.parametrize('locations', [
+    ['files', 'form'],
+    ['files', 'json'],
+    ['form', 'json'],
+    ['form_and_files', 'json'],
+    ['form_and_files', 'form'],
+    ['form_and_files', 'files'],
+    ['json_or_form', 'json'],
+    ['json_or_form', 'files'],
+    ['json_or_form', 'form'],
+    ['json_or_form', 'form_and_files'],
+])
+def test_multiple_input_body_location(app, locations):
+    with pytest.raises(RuntimeError):
+        @app.route('/foo')
+        @app.input(FooSchema, locations[0])
+        @app.input(BarSchema, locations[1])
+        def foo(query):
+            pass
+
+
 def test_bad_input_location(app):
     with pytest.raises(ValueError):
         @app.route('/foo')
-        @input(QuerySchema, 'bad')
+        @app.input(QuerySchema, 'bad')
         def foo(query):
             pass
 
@@ -103,22 +216,22 @@ def test_input_with_dict_schema(app, client):
     }
 
     @app.get('/foo')
-    @input(dict_schema, 'query')
+    @app.input(dict_schema, 'query')
     def foo(query):
         return query
 
     @app.post('/bar')
-    @input(dict_schema, schema_name='MyName')
+    @app.input(dict_schema, schema_name='MyName')
     def bar(body):
         return body
 
     @app.post('/baz')
-    @input(dict_schema)
+    @app.input(dict_schema)
     def baz(body):
         return body
 
     @app.post('/spam')
-    @input(dict_schema)
+    @app.input(dict_schema)
     def spam(body):
         return body
 
@@ -193,22 +306,22 @@ def test_input_body_example(app, client):
     }
 
     @app.post('/foo')
-    @input(FooSchema, example=example)
+    @app.input(FooSchema, example=example)
     def foo():
         pass
 
     @app.post('/bar')
-    @input(FooSchema, examples=examples)
+    @app.input(FooSchema, examples=examples)
     def bar():
         pass
 
     @app.route('/baz')
     class Baz(MethodView):
-        @input(FooSchema, example=example)
+        @app.input(FooSchema, example=example)
         def get(self):
             pass
 
-        @input(FooSchema, examples=examples)
+        @app.input(FooSchema, examples=examples)
         def post(self):
             pass
 
